@@ -1,18 +1,18 @@
-/* cluttermm-gtk - a C++ wrapper for clutter-gtk
+/* clutter-gtkmm - a C++ wrapper for clutter-gtk
  *
- * Copyright 2007 The cluttermm Development Team
+ * Copyright 2008-2009 The cluttermm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -28,5 +28,6 @@ extern const int clutter_gtkmm_micro_version;
 #include <cluttermm.h>
 #include <clutter-gtkmm/init.h>
 #include <clutter-gtkmm/embed.h>
+#include <clutter-gtkmm/utility.h>
 
 #endif /* #ifndef LIBCLUTTER_GTKMM_H */
